/** @module array-to-object-keys
 */
declare module "array-to-object-keys" {
    /**
     * @typedef valueGenerator
     * @type {function}
     * @param {string} value Original array entry
     * @param {number} index Index of the array entry (starts at 0)
     * @returns {*} Anything that will be the object entry value
     */
    export type valueGenerator = (value: string, index: number) => any;
    /**
     * Converts an array to an object with static keys and customizable values
     * @example
     * import arrayToObjectKeys from "array-to-object-keys"
     * arrayToObjectKeys(["a", "b"])
     * // {a: null, b: null}
     * @example
     * import arrayToObjectKeys from "array-to-object-keys"
     * arrayToObjectKeys(["a", "b"], "value")
     * // {a: "value", b: "value"}
     * @example
     * import arrayToObjectKeys from "array-to-object-keys"
     * arrayToObjectKeys(["a", "b"], (key, index) => `value for ${key} #${index + 1}`)
     * // {a: "value for a #1", b: "value for b #2"}
     * @function
     * @param {string[]} array Keys for the generated object
     * @param {valueGenerator|*} [valueGenerator=null] Optional function that sets the object values based on key and index
     * @returns {object<string, *>} A generated object based on the array input
     */
    export default function(array: string[], valueGenerator?: valueGenerator | any): {
        [key: string]: any;
    };
}